;; Generated package description from logos.el  -*- no-byte-compile: t -*-
(define-package "logos" "1.2.0.0.20251126.175507" "Simple focus mode and extras" '((emacs "27.1")) :commit "f372494ff0a87ab82bf09c661877a78109fc75ec" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :keywords '("convenience" "focus" "writing" "presentation" "narrowing") :url "https://github.com/protesilaos/logos")
